@@ -21,6 +21,9 @@
 
 #define VOICE_MARKER_SIZE 10
 
+static ChamplainPathLayer *path_layer;
+static ChamplainPathLayer *path;
+
 GClueSimple *simple = NULL;
 GClueClient *client = NULL;
 GMainLoop *main_loop;
@@ -36,10 +39,83 @@ gchar *voice_stream;
 
 VoiceInfo *voiceinfo;
 
+ChamplainMarkerLayer *layer;
+
 #define N_COLS 2
 #define COL_ID 0
 #define COL_NAME 1
 
+typedef struct
+{
+	ChamplainView *view;
+	ChamplainMarker *marker;
+} LocationCallbackData;
+
+void
+marker_function (ChamplainMarker *self,
+		 gdouble          dx,
+		 gdouble          dy,
+		 ClutterEvent    *event,
+		 gpointer         user_data)
+{
+        gchar *station, *station_link;
+	gchar *markup;
+	guint context_id;
+	GstPlayer *player;
+	VoiceInfo *voinfo;
+	player = gst_player_new (NULL, gst_player_g_main_context_signal_dispatcher_new(NULL));
+	voinfo = gnome_voice_file_loader (voinfo, voice_filename);
+	while (voinfo != NULL) {
+	         if (strcasecmp(voinfo->location, station_link)==0) {
+		        station = (gchar *)champlain_label_get_text (CHAMPLAIN_LABEL (self));
+		        station_link = strtok(station, "\n");
+		        player = gst_player_new (NULL, gst_player_g_main_context_signal_dispatcher_new(NULL));
+			gst_player_set_uri (GST_PLAYER (player), voinfo->stream);
+			gst_player_play(GST_PLAYER (player));
+		}
+		voinfo = voinfo->next;
+	}
+	if (user_data != NULL) {
+		champlain_label_set_text (CHAMPLAIN_LABEL (self), user_data);
+	}
+	/* g_signal_connect(CHAMPLAIN_LOCATION(self), "button-press", G_CALLBACK (on_new_station_clicked), user_data); */
+	return;
+}
+
+ChamplainMarkerLayer *
+create_marker_layer (G_GNUC_UNUSED ChamplainView *view, ChamplainPathLayer **path)
+{
+	ClutterActor *marker;
+	ClutterActor *layer_actor;
+	ClutterColor city_color = { 0x10, 0x10, 0x10, 0xbb };
+	ClutterColor city_a_color = { 0x36, 0x89, 0xe6, 0xbb };
+	ClutterColor city_b_color = { 0xde, 0x3e, 0x80, 0xbb };
+	ClutterColor city_c_color = { 0xa5, 0x6d, 0xe2, 0xbb };
+	ClutterColor city_d_color = { 0x71, 0x53, 0x44, 0xbb };
+	ClutterColor city_e_color = { 0xab, 0xac, 0xae, 0xbb };
+	ClutterColor city_f_color = { 0x48, 0x5a, 0x6c, 0xbb };
+	ClutterColor text_color = { 0xff, 0xff, 0xff, 0xff };
+	LocationCallbackData callback_data;
+	gchar *station = NULL;
+	*path = champlain_path_layer_new ();
+	layer = champlain_marker_layer_new_full (CHAMPLAIN_SELECTION_SINGLE);
+	layer_actor = CLUTTER_ACTOR (layer);
+	marker = champlain_label_new_from_file ("icons/emblem-generic.png", NULL);
+	station = g_strdup("Los Angeles, California\n<span size=\"small\">Sondre Lerche</span>");
+	champlain_label_set_text (CHAMPLAIN_LABEL (marker), station);
+	champlain_label_set_use_markup (CHAMPLAIN_LABEL (marker), TRUE);
+	champlain_label_set_color (CHAMPLAIN_LABEL (marker), &city_a_color);
+	champlain_label_set_text_color (CHAMPLAIN_LABEL (marker), &text_color);
+	champlain_location_set_location (CHAMPLAIN_LOCATION (marker), lat_gps, lon_gps);
+	champlain_marker_layer_add_marker (layer, CHAMPLAIN_MARKER (marker));
+	champlain_marker_animate_in(CHAMPLAIN_MARKER (marker));
+	/* champlain_path_layer_add_node (*path, CHAMPLAIN_LOCATION (marker)); */
+	g_signal_connect(CHAMPLAIN_LOCATION(marker), "button-press", G_CALLBACK(marker_function), station);
+	champlain_marker_layer_set_all_markers_draggable (layer);
+	clutter_actor_show (layer_actor);
+	return layer;
+}
+
 static gboolean
 on_location_timeout (gpointer user_data)
 {
@@ -271,7 +347,7 @@ create_voice_marker (void)
 	/* Add the circle to the voice_marker */
 	clutter_container_add_actor (CLUTTER_CONTAINER (voice_marker), bg);
 	clutter_actor_set_anchor_point_from_gravity (bg, CLUTTER_GRAVITY_CENTER);
-	clutter_actor_set_position (bg, 0, 0);
+	clutter_actor_set_position (bg, lat_gps, lon_gps);
 	/* Echo circle ----------------------------------------------- */
 	bg = clutter_cairo_texture_new (2 * VOICE_MARKER_SIZE,
 					2 * VOICE_MARKER_SIZE);
@@ -289,7 +365,7 @@ create_voice_marker (void)
 	/* Add the circle to the voice_marker */
 	clutter_container_add_actor (CLUTTER_CONTAINER (voice_marker), bg);
 	clutter_actor_lower_bottom (bg); /* Ensure it is under the previous circle */
-	clutter_actor_set_position (bg, 0, 0);
+	clutter_actor_set_position (bg, lat_gps, lon_gps);
 	clutter_actor_set_anchor_point_from_gravity (bg,
 						     CLUTTER_GRAVITY_CENTER);
 	/* Animate the echo circle */
@@ -344,7 +420,7 @@ create_voicegram (void)
 	/* Add the circle to the voicegram */
 	clutter_container_add_actor (CLUTTER_CONTAINER (voicegram), bg);
 	clutter_actor_set_anchor_point_from_gravity (bg, CLUTTER_GRAVITY_CENTER);
-	clutter_actor_set_position (bg, 0, 0);
+	clutter_actor_set_position (bg, lat_gps, lon_gps);
 	/* Echo circle ----------------------------------------------- */
 	bg = clutter_cairo_texture_new (2 * VOICE_MARKER_SIZE,
 					2 * VOICE_MARKER_SIZE);
@@ -362,7 +438,7 @@ create_voicegram (void)
 	/* Add the circle to the voice_marker */
 	clutter_container_add_actor (CLUTTER_CONTAINER (voicegram), bg);
 	clutter_actor_lower_bottom (bg); /* Ensure it is under the previous circle */
-	clutter_actor_set_position (bg, 0, 0);
+	clutter_actor_set_position (bg, lat_gps, lon_gps);
 	clutter_actor_set_anchor_point_from_gravity (bg,
 						     CLUTTER_GRAVITY_CENTER);
 	/* Animate the echo circle */
@@ -400,9 +476,10 @@ gps_callback (GClueSimple *simple, GpsCallbackData *data)
         GTimeVal tv = { 0 };
         const char *desc;
 
+#if 0
 	lat_gps = gclue_location_get_latitude (location);
 	lon_gps = gclue_location_get_longitude (location);
-
+#endif
 	champlain_view_center_on (CHAMPLAIN_VIEW (data->view), lat_gps, lon_gps);
 	champlain_location_set_location (CHAMPLAIN_LOCATION (data->voice_marker), lat_gps, lon_gps);
 
@@ -575,7 +652,7 @@ main (gint argc, gchar **argv)
 	GtkWidget *introduction;
 	int i = 0;
 	PageInfo page[5] = {
-		{NULL, -1, "Voice 0.7.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
+		{NULL, -1, "Voice 1.0.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
 		{NULL, -1, "Title", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Filename", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Summary", GTK_ASSISTANT_PAGE_SUMMARY, TRUE},		
@@ -596,7 +673,7 @@ main (gint argc, gchar **argv)
 	  fprintf(stderr, "No Voice Stream typed on the command line\n");
 	}
 
-	context = g_option_context_new ("- Voice 0.7.0");
+	context = g_option_context_new ("- Voice 1.0.0");
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	if (!g_option_context_parse (context, &argc, &argv, &error)) {
@@ -609,10 +686,10 @@ main (gint argc, gchar **argv)
 	introduction = gtk_assistant_new();
 	gtk_container_add (GTK_WINDOW (window), introduction);
 	gtk_widget_set_size_request(GTK_WIDGET(introduction), 640, 480);
-	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 0.7.0");
+	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 1.0.0");
 	g_signal_connect(G_OBJECT(introduction), "destroy",
 			 G_CALLBACK(gtk_main_quit), NULL);
-	page[0].widget = gtk_label_new(_("Welcome to Voice 0.7.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
+	page[0].widget = gtk_label_new(_("Welcome to Voice 1.0.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
 	page[1].widget = gtk_box_new(FALSE, 5);
 	title_label = gtk_label_new(_("Title:"));
 	title_entry = gtk_entry_new();
@@ -690,7 +767,7 @@ main (gint argc, gchar **argv)
 				 GST_TAG_TITLE, g_get_real_name(),
 				 GST_TAG_ARTIST, g_get_real_name(),
 				 GST_TAG_ALBUM, gtk_entry_get_text(filename_entry),
-				 GST_TAG_COMMENT, "Voice 0.7.0",
+				 GST_TAG_COMMENT, "Voice 1.0.0",
 				 GST_TAG_DATE, g_date_time_format_iso8601 (datestamp),
 				 NULL);
 	g_date_time_unref (datestamp);
@@ -713,8 +790,12 @@ main (gint argc, gchar **argv)
 	clutter_actor_set_size (CLUTTER_ACTOR (second), 80, 60);
 	clutter_container_add_actor (CLUTTER_CONTAINER (stage), second);
 	/* Create the voice_marker layer */
-	layer = champlain_marker_layer_new_full (CHAMPLAIN_SELECTION_SINGLE);
+	// layer = champlain_marker_layer_new_full (CHAMPLAIN_SELECTION_SINGLE);
 	world = champlain_marker_layer_new_full (CHAMPLAIN_SELECTION_SINGLE);
+	layer = create_marker_layer (actor, &path);
+	champlain_view_add_layer (actor, CHAMPLAIN_LAYER (path));
+	champlain_view_add_layer (actor, CHAMPLAIN_LAYER (layer));
+
 	clutter_actor_show (CLUTTER_ACTOR (layer));
 	clutter_actor_show (CLUTTER_ACTOR (world));
 	champlain_view_add_layer (CHAMPLAIN_VIEW (actor), CHAMPLAIN_LAYER (layer));
@@ -750,10 +831,7 @@ main (gint argc, gchar **argv)
 	champlain_view_center_on (CHAMPLAIN_VIEW (actor), lat_gps, lon_gps);
 	g_object_set (G_OBJECT (second), "zoom-level", 6,
 		      "kinetic-mode", TRUE, NULL);
-#if 0
-	champlain_view_center_on (CHAMPLAIN_VIEW (second), (gdouble)*voiceinfo->location->lat, (gdouble)*voiceinfo->location->lon);
-#endif
-	champlain_view_center_on (CHAMPLAIN_VIEW (second), lat_gps, lon_gps);
+	champlain_view_center_on (CHAMPLAIN_VIEW (second), lat, lon);
 	/* Create callback that updates the map periodically */
 	callback_data.view = CHAMPLAIN_VIEW (actor);
 	callback_data.voice_marker = CHAMPLAIN_MARKER (voice_marker);
