@@ -3,11 +3,11 @@
 
 #include <geoclue.h>
 
-double lat = 21.293352;
-double lon = -157.839583;
+double lat = 34.0223563;
+double lon = -118.2873057;
 
-double lat_gps = 21.293352;
-double lon_gps = -157.839583;
+double lat_gps = 34.0223563;
+double lon_gps = -118.2873057;
 
 typedef struct
 {
@@ -40,4 +40,8 @@ static void gv_wizard_cancel (GtkAssistant *, gpointer);
 static void gv_wizard_close (GtkAssistant *, gpointer);
 static void gv_wizard_apply (GtkAssistant *, gpointer);
 
+ChamplainMarkerLayer *create_marker_layer (ChamplainView *view, ChamplainPathLayer **path);
+
+void marker_function (ChamplainMarker *self, gdouble dx, gdouble dy, ClutterEvent *event, gpointer user_data);
+
 #endif /* GNOME_VOICE_MAIN_H */
